About
--------------------------------------------


ccgallery is a minimal gallery application for Django designed to showcase products, services or anything else that fits into the 'category > thing' model.

ccgallery comes bundled with `fancyBox`_ which is licensed under a `creative commons attribution non-commercial license`_. If you plan on using this app within a commercial context, then you will need to either refrain from using the `fancyBox`_ component or pay a `license fee`_ for commercial usage.

.. _fancybox: http://fancyapps.com/fancybox/
.. _license fee: http://sites.fastspring.com/fancyapps/product/store
.. _creative commons attribution non-commercial license: http://creativecommons.org/licenses/by-nc/3.0/
